# PSQF 6243 Example 3 using R

# Set width of output and  number of digits to be printed
options("width"=120, "digits"=8) 

# Use this to turn off scientific notation: 
# "fixed notation will be preferred unless it is more than 'scipen' digits wide"
options(scipen=999)

# turn off stars for different alpha levels
options(show.signif.stars=FALSE)

if (!require("readxl")) install.packages("readxl")
library(readxl) # To import excel XLSX data with labels as table

if (!require("expss")) install.packages("expss")
library(expss) # To add variable and value labels, sorting

if (!require("psych")) install.packages("psych")
library(psych) # To add descriptive summary functions

if (!require("multcomp")) install.packages("multcomp")
library(multcomp) # To do glht linear combinations in GLMs

if (!require("ppcor")) install.packages("ppcor")
library(ppcor) # To get partial correlations

if (!require("TeachingDemos")) install.packages("TeachingDemos")
library(TeachingDemos) # To create text output files using code below


################################################################################
#####            BEGIN EXAMPLE 3 DATA IMPORT AND MANIPULATION              #####
################################################################################

# Set working directory (to import and export files to)
# Paste in the folder address where "GSS_Example.xlsx" is saved in quotes
setwd("C:/Dropbox/22SP_PSQF6243/PSQF6243_Example3")

# Import GSS_Example.xlsx data from working directory -- path = file name
Example3 = read_excel(path="GSS_Example.xlsx", sheet="GSS_Example") 
# Convert to data frame to use for analysis
Example3 = as.data.frame(Example3)

# Label variables used below (add descriptive titles) using comments instead
#   because variable labels are not allowed in many analysis packages
# Format: name: Descriptive Variable Label
# workclass: 1=Lower, 2=Middle, 3=Upper
# age:       Years of Age
# educ:      educ: Years of Education
# happy:     happy: 5-Category Happy Rating
# income:    income: Annual Income in 1000s

# Open external file to save results to
txtStart(file="Example3_R_Output.txt")


################################################################################
#####                BEGIN EXAMPLE 3 DATA DESCRIPTION                      #####
################################################################################

print("R Descriptive Statistics for Quantitative or Ordinal Variables")
describe(x=Example3[ , c("income","age","educ","happy")])

print("R Descriptive Statistics for Categorical Variables")
prop.table(table(x=Example3$workclass,useNA="ifany"))
prop.table(table(x=Example3$happy,useNA="ifany"))

txtComment(" ") # insert blank space in output


################################################################################
#####         BEGIN PREDICTION OF INCOME BY 3-CATEGORY WORKCLASS           #####
################################################################################

# R code to create indicator-dummy-coded binary predictors
Example3$LvM=NA; Example3$LvU=NA  # Make 2 new empty variables 
Example3$LvM[which(Example3$workclass==1)]=0  # Replace each for lower
Example3$LvU[which(Example3$workclass==1)]=0
Example3$LvM[which(Example3$workclass==2)]=1  # Replace each for middle
Example3$LvU[which(Example3$workclass==2)]=0
Example3$LvM[which(Example3$workclass==3)]=0  # Replace each for upper
Example3$LvU[which(Example3$workclass==3)]=1
# LvM: Low=0 vs Mid=1 Class
# LvU: Low=0 vs Upp=1 Class

print("R GLM Predicting Income from 2 New Variables for workclass")
ModelClass = lm(data=Example3, formula=income~1+LvM+LvU)
anova(ModelClass)   # anova to print residual variance
summary(ModelClass) # summary to print fixed effects solution 
confint(ModelClass, level=.95) # confint for level% CI for fixed effects

print("R Ask for predicted income per group and group differences")
print("In number lists below, values are multiplier for each fixed effect IN ORDER")
PredClass = glht(model=ModelClass, linfct=rbind(
  "Pred Income: Low"  = c(1, 0, 0),  
  "Pred Income: Mid"  = c(1, 1, 0), 
  "Pred Income: Upp"  = c(1, 0, 1), 
  "Low vs Mid Diff"   = c(0, 1, 0),
  "Low vs Upp Diff"   = c(0, 0, 1),
  "Mid vs Upp Diff"   = c(0,-1, 1)))
print("Save glht linear combination results with unadjusted p-values and 95% CIs")
SavePredClass = summary(PredClass, test=adjusted("none")) 
print(SavePredClass); confint(PredClass, level=.95, calpha=univariate_calpha())

# R code to compute effect sizes from stored model and GLHT results
PredClassPartialD=(2*SavePredClass$test$tstat)/sqrt(ModelClass$df.residual)
PredClassPartialR=SavePredClass$test$tstat/
             sqrt(SavePredClass$test$tstat^2+ModelClass$df.residual)
# Concatenate effect sizes to results table for mean differences
data.frame(Estimate=SavePredClass$test$coefficients, pvalue=SavePredClass$test$pvalues, 
           PartialD=PredClassPartialD, PartialR=PredClassPartialR)


txtComment(" ") # insert blank space in output


################################################################################
#####           BEGIN PREDICTION OF INCOME BY QUADRATIC AGE                #####
################################################################################

# R code to make new age variable centered at 18 (minimum in sample)
Example3$age18=Example3$age-18 # age18: Age (0=18 years) 

print("R GLM Predicting Income from Linear Centered Age")
ModelLinAge = lm(data=Example3, formula=income~1+age18)
anova(ModelLinAge)   # anova to print residual variance
summary(ModelLinAge) # summary to print fixed effects solution 
confint(ModelLinAge, level=.95) # confint to print level% CI for fixed effects

print("R Ask for predicted income for example ages")
print("In number lists below, values are multiplier for each fixed effect IN ORDER")
PredLinAge = glht(model=ModelLinAge, linfct=rbind(
  "Pred Income: Age 30 (age18=12)" = c(1,12),  
  "Pred Income: Age 50 (age18=32)" = c(1,32), 
  "Pred Income: Age 70 (age18=52)" = c(1,52)))
print("Print glht linear combination results with unadjusted p-values and 95% CIs")
summary(PredLinAge, test=adjusted("none")) 
confint(PredLinAge, level=.95, calpha=univariate_calpha())

txtComment(" ") # insert blank space in output


print("R GLM Predicting Income from Linear+Quadratic Centered Age")
ModelQuadAge = lm(data=Example3, formula=income~1+age18+I(age18^2)) # I(x^2) squares predictor
anova(ModelQuadAge)   # anova to print residual variance
summary(ModelQuadAge) # summary to print fixed effects solution 
confint(ModelQuadAge, level=.95) # confint to print level% CI for fixed effects

print("R Ask for predicted income and predicted linear age slopes for example ages")
print("In number lists below, values are multiplier for each fixed effect IN ORDER")
PredQuadAge = glht(model=ModelQuadAge, linfct=rbind(
  "Pred Income: Age 30 (age18=12)" = c(1,12, 144),  
  "Pred Income: Age 50 (age18=32)" = c(1,32,1024), 
  "Pred Income: Age 70 (age18=52)" = c(1,52,2704),
  "Pred Linear Age Slope: Age 30 (age18=12)" = c(0,1, 24),
  "Pred Linear Age Slope: Age 50 (age18=32)" = c(0,1, 64),
  "Pred Linear Age Slope: Age 70 (age18=52)" = c(0,1,104)))
print("Print glht linear combination results with unadjusted p-values and 95% CIs")
summary(PredQuadAge, test=adjusted("none")) 
confint(PredQuadAge, level=.95, calpha=univariate_calpha())
#  Not getting partial R effect sizes because linear+quadratic slopes work together

txtComment(" ") # insert blank space in output


################################################################################
#####     BEGIN PREDICTION OF INCOME BY PIECEWISE SLOPES FOR EDUCATION     #####
################################################################################

# R code to make to make 3 new variables for sections of education
# Make 3 new empty variables 
Example3$lessHS=NA; Example3$gradHS=NA; Example3$overHS=NA 
# Replace each for educ less than 12
Example3$lessHS[which(Example3$educ<12)]=Example3$educ[which(Example3$educ<12)]-11  
Example3$gradHS[which(Example3$educ<12)]=0
Example3$overHS[which(Example3$educ<12)]=0  
# Replace each for educ greater or equal to 12
Example3$lessHS[which(Example3$educ>=12)]=0 
Example3$gradHS[which(Example3$educ>=12)]=1  
Example3$overHS[which(Example3$educ>=12)]=Example3$educ[which(Example3$educ>=12)]-12
# lessHS: Slope for Years Ed Less Than High School
# gradHS: Acute Bump for Graduating High School
# overHS: Slope for Years Ed After High School

print("R GLM Predicting Income from 3 Piecewise Linear Slopes for Education")
ModelEd3 = lm(data=Example3, formula=income~1+lessHS+gradHS+overHS)
anova(ModelEd3)   # anova to print residual variance
SaveModelEd3 = summary(ModelEd3) # summary to print fixed effects solution 
print(SaveModelEd3); confint(SaveModelEd3, level=.95) # confint for level% CI for fixed effects

print("R Example of how to compare slopes")
print("In number lists below, values are multiplier for each fixed effect IN ORDER")
PredEd3 = glht(model=ModelEd3, linfct=rbind(
  "Diff in ed slope:  2-11 vs 11-12" = c(0,-1, 1,0),  
  "Diff in ed slope: 11-12 vs 12-20" = c(0, 0,-1,1)))
print("Save glht linear combination results with unadjusted p-values and 95% CIs")
SavePredEd3 = summary(PredEd3, test=adjusted("none")) 
print(SavePredEd3); confint(PredEd3, level=.95, calpha=univariate_calpha())

# R code to compute effect sizes from stored model fixed effects
ModelEd3PartialR=SaveModelEd3$coefficients[,"t value"]/
            sqrt(SaveModelEd3$coefficients[,"t value"]^2+ModelEd3$df.residual)
# Concatenate effect sizes to results table for fixed effects
data.frame(SaveModelEd3$coefficients, PartialR=ModelEd3PartialR)

# R code to compute effect sizes from stored glht results
PredEd3PartialR=SavePredEd3$test$tstat/sqrt(SavePredEd3$test$tstat^2+ModelEd3$df.residual)
# Concatenate effect sizes to results table for mean differences
data.frame(Estimate=SavePredEd3$test$coefficients, pvalue=SavePredEd3$test$pvalues, 
           PartialR=PredEd3PartialR)

# R alternative method to compute partial correlations for fixed slopes
print("R Partial Correlation of income with lessHS")
pcor.test(Example3$income,Example3$lessHS, Example3[,c("gradHS","overHS")])
print("R Partial Correlation of income with gradHS")
pcor.test(Example3$income,Example3$gradHS, Example3[,c("lessHS","overHS")])
print("R Partial Correlation of income with overHS")
pcor.test(Example3$income,Example3$overHS, Example3[,c("lessHS","gradHS")])

txtComment(" ") # insert blank space in output


################################################################################
#####     BEGIN PREDICTION OF INCOME BY ORDINAL 5-CATEGORY HAPPINESS       #####
################################################################################

# R code to make a single happy variable centered at lowest value
Example3$happy1=Example3$happy-1 # happy1: Happy Category (0=1) 

print("R GLM Predicting Income from Linear Centered Age")
ModelHappy1 = lm(data=Example3, formula=income~1+happy1)
anova(ModelHappy1)   # anova to print residual variance
summary(ModelHappy1) # summary to print fixed effects solution 
confint(ModelHappy1, level=.95) # confint for level% CI for fixed effects


# R code to create 4 new sequential-dummy-coded predictors for happy
# Make 4 new empty variables 
Example3$h1v2=NA; Example3$h2v3=NA; Example3$h3v4=NA; Example3$h4v5=NA; 
# Replace each with 0 values
Example3$h1v2[which(Example3$happy<2)]=0  
Example3$h2v3[which(Example3$happy<3)]=0
Example3$h3v4[which(Example3$happy<4)]=0 
Example3$h4v5[which(Example3$happy<5)]=0
# Replace each with 1 values
Example3$h1v2[which(Example3$happy>=2)]=1  
Example3$h2v3[which(Example3$happy>=3)]=1
Example3$h3v4[which(Example3$happy>=4)]=1 
Example3$h4v5[which(Example3$happy>=5)]=1
# h1v2: Slope from Happy 1 to 2
# h2v3: Slope from Happy 2 to 3
# h3v4: Slope from Happy 3 to 4
# h4v5: Slope from Happy 4 to 5

print("R GLM Predicting Income from Sequential Slopes for Happy")
ModelHappy5 = lm(data=Example3, formula=income~1+h1v2+h2v3+h3v4+h4v5)
anova(ModelHappy5)   # anova to print residual variance
SaveModelHappy5 = summary(ModelHappy5) # summary to print fixed effects solution 
print(SaveModelHappy5); confint(ModelHappy5, level=.95) # confint for level% CI for fixed effects

print("R Example of how to compare slopes")
print("In number lists below, values are multiplier for each fixed effect IN ORDER")
PredHappy5 = glht(model=ModelHappy5, linfct=rbind(
        "Diff in Slope 1-2 vs Slope 2-3" = c(0,-1, 1, 0, 0),  
        "Diff in Slope 2-3 vs Slope 3-4" = c(0, 0,-1, 1, 0),
        "Diff in Slope 3-4 vs Slope 4-5" = c(0, 0, 0,-1, 1)))
print("Print glht linear combination results with unadjusted p-values and 95% CIs")
SavePredHappy5 = summary(PredHappy5, test=adjusted("none")) 
print(SavePredHappy5); confint(PredHappy5, level=.95, calpha=univariate_calpha())

# R code to compute effect sizes from stored model fixed effects
ModelHappy5PartialR=SaveModelHappy5$coefficients[,"t value"]/
               sqrt(SaveModelHappy5$coefficients[,"t value"]^2+ModelHappy5$df.residual)
# Concatenate effect sizes to results table for fixed effects
data.frame(SaveModelHappy5$coefficients, PartialR=ModelHappy5PartialR)

# R code to compute effect sizes from stored glht results
PredHappy5PartialR=SavePredHappy5$test$tstat/
              sqrt(SavePredHappy5$test$tstat^2+ModelHappy5$df.residual)
# Concatenate effect sizes to results table for mean differences
data.frame(Estimate=SavePredHappy5$test$coefficients, pvalue=SavePredHappy5$test$pvalues, 
           PartialR=PredHappy5PartialR)

# R alternative method to compute partial correlations for fixed slopes
print("R Partial Correlation of income with h1v2")
pcor.test(Example3$income,Example3$h1v2, Example3[,c("h2v3","h3v4","h4v5")])
print("R Partial Correlation of income with h2v3")
pcor.test(Example3$income,Example3$h2v3, Example3[,c("h1v2","h3v4","h4v5")])
print("R Partial Correlation of income with h3v4")
pcor.test(Example3$income,Example3$h3v4, Example3[,c("h1v2","h2v3","h4v5")])
print("R Partial Correlation of income with h4v5")
pcor.test(Example3$income,Example3$h4v5, Example3[,c("h1v2","h2v3","h3v4")])


# Close output text file
txtStop()


