// Prevent "more" messages from appearing
set more off
// Control line length
set linesize 150

******************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION     *******
******************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
// \\Client\ precedes path in Virtual Desktop outside H drive;
cd "C:\Dropbox\22SP_PSQF6243\PSQF6243_Example3"

// Import GSS_Example.xlsx data from working directory using exact file name
// To change all variable names to lowercase, remove "case(preserve")
clear // Clear before means close any open data
import excel "GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (if need to start over)

// Label variables and apply value formats for variables used below
// label variable name   "name: Descriptive Variable Label"
label variable workclass "workclass: 1=Lower, 2=Middle, 3=Upper"  
label variable age       "age: Years of Age"
label variable educ      "educ: Years of Education"
label variable happy     "happy: 5-Category Happy Rating"
label variable income    "income: Annual Income in 1000s"

// Select cases complete on variables to be used
egen nmiss = rowmiss(income workclass age educ happy)
drop if nmiss>0
// Now dataset is ready to use

// Save results to separate text file
log using Example3_STATA_Output.log, replace 

   
******************************************************************************
*******               BEGIN EXAMPLE 3 DATA DESCRIPTION                 *******
******************************************************************************

display "STATA Descriptive Statistics for Quantitative and Ordinal Variables"
summarize income age educ happy

display "SAS Descriptive Statistics for Categorical Variables"
tabulate workclass
tabulate happy


******************************************************************************
*******       BEGIN PREDICTION OF INCOME BY 3-CATEGORY WORKCLASS       *******
******************************************************************************

// STATA code to create 2 new indicator-dummy-coded binary predictors
gen LvM=. // Make two new empty variables
gen LvU=.
replace LvM=0 if workclass==1 // Replace each for lower
replace LvU=0 if workclass==1
replace LvM=1 if workclass==2 // Replace each for middle
replace LvU=0 if workclass==2
replace LvM=0 if workclass==3 // Replace each for upper
replace LvU=1 if workclass==3
label variable LvM "LvM: Low=0 v Mid=1 Class"
label variable LvU "LvU: Low=0 v Upp=1 Class"

display "STATA GLM Predicting Income from 2 New Variables for workclass"
regress income c.LvM c.LvU, level(95)
// Ask for predicted income per group and group differences
   lincom _cons*1 + c.LvM*0  + c.LvU*0  // Pred Income: Low 
   lincom _cons*1 + c.LvM*1  + c.LvU*0  // Pred Income: Mid  
   lincom _cons*1 + c.LvM*0  + c.LvU*1  // Pred Income: Upp  
   lincom           c.LvM*1  + c.LvU*0  // Low vs Mid Diff 
   lincom           c.LvM*0  + c.LvU*1  // Low vs Upp Diff 
   lincom           c.LvM*-1 + c.LvU*1  // Mid vs Upp Diff 
  
// STATA code to compute effect sizes from stored results per lincom
lincom c.LvM*1  + c.LvU*0 // Low vs Mid Diff   
   display "PartialD= " (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.LvM*0  + c.LvU*1  // Low vs Upp Diff 
   display "PartialD= " (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.LvM*-1 + c.LvU*1  // Mid vs Upp Diff 
   display "PartialD= " (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
 

******************************************************************************
*******       BEGIN PREDICTION OF INCOME BY QUADRATIC AGE              *******
******************************************************************************

// STATA code to create 1 new age variable centered at 18 (minimum in sample)
gen age18=age-18
label variable age18 "age18: Age (0=18 years)"

display "STATA GLM Predicting Income from Linear Centered Age (0=18)"
regress income c.age18, level(95)
// Ask for predicted income for example ages
   lincom _cons*1 + c.age18*12  // Pred Income: Age 30 (age18=12)
   lincom _cons*1 + c.age18*32  // Pred Income: Age 50 (age18=32)
   lincom _cons*1 + c.age18*52  // Pred Income: Age 70 (age18=52)

display  "STATA GLM Predicting Income from Linear+Quadratic Centered Age (0=18)"
regress income c.age18 c.age18#c.age18, level(95) // Hashtag multiplies predictors
// Ask for predicted income for example ages
   lincom _cons*1 + c.age18*12 + c.age18#c.age18*144  // Pred Income: Age 30 (age18=12)
   lincom _cons*1 + c.age18*32 + c.age18#c.age18*1024 // Pred Income: Age 50 (age18=32)
   lincom _cons*1 + c.age18*52 + c.age18#c.age18*2704 // Pred Income: Age 70 (age18=52)
// Linear age slope changes by 2*quadratic coefficient, so multiply age*2
   lincom  c.age18*1 + c.age18#c.age18*24  // Pred Linear Age Slope: Age 30 (age18=12)
   lincom  c.age18*1 + c.age18#c.age18*64  // Pred Linear Age Slope: Age 50 (age18=32)
   lincom  c.age18*1 + c.age18#c.age18*104 // Pred Linear Age Slope: Age 70 (age18=52)
// Not getting partial R effect sizes because linear+quadratic slopes work together


******************************************************************************
*******  BEGIN PREDICTION OF INCOME BY PIECEWISE SLOPES FOR EDUCATION  *******
******************************************************************************
          
// STATA code to create 3 new predictor variables for sections of education
gen lessHS=. // Make 3 new empty variables
gen gradHS=.
gen overHS=.
// Replace each for educ less than 12
replace lessHS=educ-11 if educ <  12
replace gradHS=0       if educ <  12
replace overHS=0       if educ <  12
// Replace each for educ greater or equal to 12
replace lessHS=0       if educ >= 12 
replace gradHS=1       if educ >= 12
replace overHS=educ-12 if educ >= 12
// Label variables
label variable lessHS "lessHS: Slope for Years Ed Less Than High School"
label variable gradHS "gradHS: Acute Bump for Graduating High School"
label variable overHS "overHS: Slope for Years Ed After High School"

display "STATA GLM Predicting Income from 3 Piecewise Linear Slopes for Education"
regress income c.lessHS c.gradHS c.overHS, level(95)
// Example of how to compare slopes
   lincom c.lessHS*-1 + c.gradHS*1 // Diff in ed slope:  2-11 vs 11-12
   lincom c.gradHS*-1 + c.overHS*1 // Diff in ed slope: 11-12 vs 12-20
   
// STATA code to compute effect sizes from stored results per lincom
lincom c.lessHS*1 // Slope for 2-11 years  
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.gradHS*1 // Slope for 11-12 years 
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.overHS*1 // Slope for 12+ years 
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.lessHS*-1 + c.gradHS*1 // Diff in ed slope:  2-11 vs 11-12
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))   
lincom c.gradHS*-1 + c.overHS*1 // Diff in ed slope: 11-12 vs 12-20
   display "PartialR= " (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   
// STATA alternative method to compute partial correlations for fixed slopes
display "STATA Partial Correlations of Income with Education Slopes"
pcorr income lessHS gradHS overHS

   
******************************************************************************
*******   BEGIN PREDICTION OF INCOME BY ORDINAL 5-CATEGORY HAPPINESS   *******
******************************************************************************

// STATA code to create 1 new happy variable centered at lowest value
gen happy1=happy-1
label variable happy1 "happy1: Happy Category (0=1)"
   
display "STATA GLM Predicting Income from Linear Centered Happy (0=1)"
regress income c.happy1, level(95)

// STATA code to make 4 new sequential-dummy-coded variables for happy
// Make 4 new empty variables
gen h1v2=. 
gen h2v3=. 
gen h3v4=.
gen h4v5=.
// Replace each with 0 values
replace h1v2=0 if happy<2
replace h2v3=0 if happy<3
replace h3v4=0 if happy<4
replace h4v5=0 if happy<5
// Replace each with 1 values
replace h1v2=1 if happy>=2
replace h2v3=1 if happy>=3
replace h3v4=1 if happy>=4
replace h4v5=1 if happy==5
// Label variables
label variable h1v2 "Slope from Happy 1 to 2"
label variable h2v3 "Slope from Happy 2 to 3"
label variable h3v4 "Slope from Happy 3 to 4"
label variable h4v5 "Slope from Happy 4 to 5"

display "STATA GLM Predicting Income from Sequential Slopes for Happy"
regress income c.h1v2 c.h2v3 c.h3v4 c.h4v5, level(95)
// Example of how to compare slopes
   lincom c.h1v2*-1 + c.h2v3*1 // Diff in Slope 1-2 vs Slope 2-3
   lincom c.h2v3*-1 + c.h3v4*1 // Diff in Slope 2-3 vs Slope 3-4
   lincom c.h3v4*-1 + c.h4v5*1 // Diff in Slope 3-4 vs Slope 4-5

// STATA code to compute effect sizes from stored results per lincom
lincom c.h1v2*1 // Slope for 1-2 happy
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.h2v3*1 // Slope for 2-3 happy
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.h3v4*1 // Slope for 3-4 happy
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.h4v5*1 // Slope for 4-5 happy
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.h1v2*-1 + c.h2v3*1 // Diff in Slope 1-2 vs Slope 2-3
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.h2v3*-1 + c.h3v4*1 // Diff in Slope 2-3 vs Slope 3-4
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.h3v4*-1 + c.h4v5*1 // Diff in Slope 3-4 vs Slope 4-5
   display "PartialR=" (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))

// STATA alternative method to compute partial correlations for fixed slopes
display "STATA Partial Correlations of Income with Happy Slopes"
pcorr income h1v2 h2v3 h3v4 h4v5
   
   
// Close log
log close  

       
       



